@@ -31,8 +31,6 @@ class Borg:
     def __init__(self):
         self.__dict__ = self.__shared_state
 
-
-
     def is_first_time(self):
         "Has the child class been invoked before?"
         result_flag = False
@@ -300,26 +298,17 @@ class Base_Page(Borg, unittest.TestCase):
             self.write(str(e))
             self.exceptions.append("Error when setting up the screenshot directory")
 
-    @staticmethod
-    def assert_true(condition, message=None):
-        """Assert a condition is True
-        :param condition: condition to check
-        :param message: message to display in case of assertion failure
-        :return: None
-        """
-
-        assert_that(condition, equal_to(True), message)
-
-    @staticmethod
-    def assert_false(condition, message=None):
-        """Assert a condition is False
-        :param condition: condition to check
-        :param message: message to display in case of assertion failure
-        :return:
-        """
-
-        assert_that(condition, equal_to(False), message)
+    def assert_true(self, condition, message=None):
+        if self.non_breakable == 'N':
+            assert_that(condition, equal_to(True), message)
+        elif self.non_breakable == 'Y':
+            print('testing')
 
+    def assert_false(self, condition, message=None):
+        if self.non_breakable == 'N':
+            assert_that(condition, equal_to(False), message)
+        elif self.non_breakable == 'Y':
+            print('testing')
 
     def get_screenshot_dir(self, os_name, os_version, browser, browser_version, overwrite_flag=False):
         "Get the name of the test"
@@ -1108,6 +1097,7 @@ class Base_Page(Borg, unittest.TestCase):
             self.write(str(e), 'debug')
             self.exceptions.append("An exception occured when scrolling up")
             return None
+
     def key_press_END(self, locator, wait_time=0.5):
         "Scroll down"
         try:
